@@ -4,8 +4,6 @@ import numba as nb
 
 from numba import cuda
 
-from PIL import Image
-
 from xarray import DataArray
 import dask.array as da
 
@@ -102,7 +100,7 @@ def arvi(nir_agg: DataArray, red_agg: DataArray, blue_agg: DataArray,
     Notes:
     ----------
     Algorithm References:
-    https://modis.gsfc.nasa.gov/sci_team/pubs/abstract_new.php?id=03667
+    - Kaufman, Y. J., & Tanre, D. (1992). Atmospherically resistant vegetation index (ARVI) for EOS-MODIS. IEEE transactions on Geoscience and Remote Sensing, 30(2), 261-270. # noqa
 
     Examples:
     ----------
@@ -282,7 +280,7 @@ def evi(nir_agg: DataArray, red_agg: DataArray, blue_agg: DataArray,
     Notes:
     ----------
     Algorithm References:
-    https://en.wikipedia.org/wiki/Enhanced_vegetation_index
+    - Wikipedia, Enhanced Vegetation Index, https://en.wikipedia.org/wiki/Enhanced_vegetation_index, Accessed Apr. 21, 2021. # noqa
 
         Examples:
     ----------
@@ -461,7 +459,7 @@ def gci(nir_agg: DataArray, green_agg: DataArray, name='gci'):
     Notes:
     ----------
     Algorithm References:
-        https://en.wikipedia.org/wiki/Enhanced_vegetation_index
+    - Wikipedia, Enhanced Vegetation Index, https://en.wikipedia.org/wiki/Enhanced_vegetation_index, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -568,7 +566,7 @@ def nbr(nir_agg: DataArray, swir2_agg: DataArray, name='nbr'):
     Notes:
     ----------
     Algorithm References:
-    https://www.usgs.gov/land-resources/nli/landsat/landsat-normalized-burn-ratio
+    - USGS, Landsat Normalized Burn Ratio, https://www.usgs.gov/land-resources/nli/landsat/landsat-normalized-burn-ratio, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -648,7 +646,7 @@ def nbr2(swir1_agg: DataArray, swir2_agg: DataArray, name='nbr2'):
     "NBR2 modifies the Normalized Burn Ratio (NBR)
     to highlight water sensitivity in vegetation and
     may be useful in post-fire recovery studies."
-    https://www.usgs.gov/land-resources/nli/landsat/landsat-normalized-burn-ratio-2
+
     Parameters
     ----------
     swir1_agg : DataArray
@@ -672,7 +670,7 @@ def nbr2(swir1_agg: DataArray, swir2_agg: DataArray, name='nbr2'):
     Notes:
     ----------
     Algorithm References:
-    https://www.usgs.gov/land-resources/nli/landsat/landsat-normalized-burn-ratio-2
+    - USGS, Landsat Normalized Burn Ratio 2, https://www.usgs.gov/land-resources/nli/landsat/landsat-normalized-burn-ratio-2, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -773,9 +771,9 @@ def ndvi(nir_agg: DataArray, red_agg: DataArray, name='ndvi'):
     Notes:
     ----------
     Algorithm References:
-    http://ceholden.github.io/open-geo-tutorial/python/chapter_2_indices.html
+    - Holden, C, Chapter 2: Your first remote sensing vegetation index, http://ceholden.github.io/open-geo-tutorial/python/chapter_2_indices.html, Accessed Apr. 21, 2021. # noqa
 
-        Examples:
+    Examples:
     ----------
     Imports
     >>> import numpy as np
@@ -878,7 +876,7 @@ def ndmi(nir_agg: DataArray, swir1_agg: DataArray, name='ndmi'):
     Notes:
     ----------
     Algorithm References:
-    https://www.usgs.gov/land-resources/nli/landsat/normalized-difference-moisture-index
+    - USGS, Normalized Difference Moisture Index, https://www.usgs.gov/land-resources/nli/landsat/normalized-difference-moisture-index, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -1087,7 +1085,7 @@ def savi(nir_agg: DataArray, red_agg: DataArray,
     Notes:
     ----------
     Algorithm References:
-     - https://www.sciencedirect.com/science/article/abs/pii/003442578890106X
+     - Huete, A. R. (1988). A soil-adjusted vegetation index (SAVI). Remote sensing of environment, 25(3), 295-309. # noqa
 
     Examples
     ----------
@@ -1243,7 +1241,7 @@ def sipi(nir_agg: DataArray, red_agg: DataArray, blue_agg: DataArray,
     Notes:
     ----------
     Algorithm References:
-    https://en.wikipedia.org/wiki/Enhanced_vegetation_index
+    - Wikipedia, Enhanced Vegetation Index, https://en.wikipedia.org/wiki/Enhanced_vegetation_index, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -1415,7 +1413,7 @@ def ebbi(red_agg: DataArray, swir_agg: DataArray, tir_agg: DataArray,
     Notes:
     ----------
     Algorithm References:
-        https://rdrr.io/cran/LSRS/man/EBBI.html
+    - RDRR.io, EBBI: Enhanced Built-Up and Bareness Index, https://rdrr.io/cran/LSRS/man/EBBI.html, Accessed Apr. 21, 2021. # noqa
 
     Examples:
     ----------
@@ -1558,17 +1556,81 @@ def _normalize_data(agg, pixel_max=255.0):
     return out
 
 
-def true_color(r, g, b, nodata=1):
+def _alpha_numpy(red, nodata):
+    a = np.where(np.logical_or(np.isnan(red), red <= nodata), 0, 255)
+    return a
+
+
+def _alpha_dask(red, nodata):
+    a = da.where(da.logical_or(da.isnan(red), red <= nodata), 0, 255)
+    return a
+
+
+def _alpha_cupy(red, nodata):
+    raise NotImplementedError('Not Supported')
+
+
+def _alpha_dask_cupy(red, nodata):
+    raise NotImplementedError('Not Supported')
+
+
+def _alpha(red, nodata=1):
+    mapper = ArrayTypeFunctionMapping(numpy_func=_alpha_numpy,
+                                      dask_func=_alpha_dask,
+                                      cupy_func=None,
+                                      dask_cupy_func=None)
+    out = mapper(red)(red.data, nodata)
+    return out
+
+
+def _true_color_numpy(r, g, b, nodata):
+    a = np.where(np.logical_or(np.isnan(r), r <= nodata), 0, 255)
+
     h, w = r.shape
+    out = np.zeros((h, w, 4), dtype=np.uint8)
 
     pixel_max = 255
+    out[:, :, 0] = (_normalize_data(r, pixel_max)).astype(np.uint8)
+    out[:, :, 1] = (_normalize_data(g, pixel_max)).astype(np.uint8)
+    out[:, :, 2] = (_normalize_data(b, pixel_max)).astype(np.uint8)
+    out[:, :, 3] = a.astype(np.uint8)
+    return out
 
-    data = np.zeros((h, w, 4), dtype=np.uint8)
-    data[:, :, 0] = (_normalize_data(r, pixel_max)).astype(np.uint8)
-    data[:, :, 1] = (_normalize_data(g, pixel_max)).astype(np.uint8)
-    data[:, :, 2] = (_normalize_data(b, pixel_max)).astype(np.uint8)
 
-    a = np.where(np.logical_or(np.isnan(r), r <= nodata), 0, 255)
-    data[:, :, 3] = a.astype(np.uint8)
+def _true_color_dask(r, g, b, nodata):
+    pixel_max = 255
+    red = (_normalize_data(r, pixel_max)).astype(np.uint8)
+    green = (_normalize_data(g, pixel_max)).astype(np.uint8)
+    blue = (_normalize_data(b, pixel_max)).astype(np.uint8)
 
-    return Image.fromarray(data, 'RGBA')
+    alpha = _alpha(r, nodata).astype(np.uint8)
+
+    out = da.stack([red, green, blue, alpha], axis=-1)
+    return out
+
+
+def _true_color_cupy(r, g, b, nodata):
+    raise NotImplementedError('Not Supported')
+
+
+def _true_color_dask_cupy(r, g, b, nodata):
+    raise NotImplementedError('Not Supported')
+
+
+def true_color(r, g, b, nodata=1, name='true_color'):
+    mapper = ArrayTypeFunctionMapping(numpy_func=_true_color_numpy,
+                                      dask_func=_true_color_dask,
+                                      cupy_func=_true_color_cupy,
+                                      dask_cupy_func=_true_color_dask_cupy)
+    out = mapper(r)(r, g, b, nodata)
+
+    # TODO: output metadata: coords, dims, atts
+    _dims = ['y', 'x', 'band']
+    _coords = {'y': r['y'],
+               'x': r['x'],
+               'band': [0, 1, 2, 3]}
+
+    return DataArray(out,
+                     dims=_dims,
+                     coords=_coords
+                     )
